"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CronClient = exports.CreateCronTriggerSchema = void 0;
const zod_1 = require("zod");
const axios_1 = require("axios");
/**
 * Schema for creating a Cron Trigger.
 */
exports.CreateCronTriggerSchema = zod_1.z.object({
    name: zod_1.z.string(),
    expression: zod_1.z.string().refine((val) => {
        // Basic cron validation regex
        const cronRegex = /^(\*|([0-9]|1[0-9]|2[0-9]|3[0-9]|4[0-9]|5[0-9])|\*\/([0-9]|1[0-9]|2[0-3])) (\*|([0-9]|1[0-9]|2[0-3])|\*\/([0-9]|1[0-9]|2[0-3])) (\*|([1-9]|1[0-9]|2[0-9]|3[0-1])|\*\/([1-9]|1[0-9]|2[0-9]|3[0-1])) (\*|([1-9]|1[0-2])|\*\/([1-9]|1[0-2])) (\*|([0-6])|\*\/([0-6]))$/;
        return cronRegex.test(val);
    }, 'Invalid cron expression'),
    input: zod_1.z.record(zod_1.z.any()).optional(),
    additionalMetadata: zod_1.z.record(zod_1.z.string()).optional(),
});
/**
 * Client for managing Cron Triggers.
 */
class CronClient {
    /**
     * Initializes a new instance of CronClient.
     * @param tenantId - The tenant identifier.
     * @param config - Client configuration settings.
     * @param api - API instance for REST interactions.
     * @param adminClient - Admin client for administrative operations.
     */
    constructor(tenantId, config, api, adminClient) {
        this.tenantId = tenantId;
        this.config = config;
        this.api = api;
        this.adminClient = adminClient;
        this.logger = config.logger('Cron', this.config.log_level);
    }
    /**
     * Retrieves the Cron ID from a CronWorkflows object or a string.
     * @param cron - The CronWorkflows object or Cron ID as a string.
     * @returns The Cron ID as a string.
     */
    getCronId(cron) {
        return typeof cron === 'string' ? cron : cron.metadata.id;
    }
    /**
     * Creates a new Cron workflow.
     * @param workflow - The workflow identifier or Workflow object.
     * @param cron - The input data for creating the Cron Trigger.
     * @returns A promise that resolves to the created CronWorkflows object.
     * @throws Will throw an error if the input is invalid or the API call fails.
     */
    create(workflow, cron) {
        return __awaiter(this, void 0, void 0, function* () {
            var _a, _b, _c;
            const workflowId = typeof workflow === 'string' ? workflow : workflow.id;
            // Validate cron input with zod schema
            try {
                const parsedCron = exports.CreateCronTriggerSchema.parse(cron);
                const response = yield this.api.cronWorkflowTriggerCreate(this.tenantId, workflowId, {
                    cronName: parsedCron.name,
                    cronExpression: parsedCron.expression,
                    input: (_a = parsedCron.input) !== null && _a !== void 0 ? _a : {},
                    additionalMetadata: (_b = parsedCron.additionalMetadata) !== null && _b !== void 0 ? _b : {},
                });
                return response.data;
            }
            catch (err) {
                if (err instanceof zod_1.z.ZodError) {
                    throw new Error(`Invalid cron input: ${err.message}`);
                }
                if (err instanceof axios_1.AxiosError) {
                    throw new Error(JSON.stringify((_c = err.response) === null || _c === void 0 ? void 0 : _c.data.errors));
                }
                throw err;
            }
        });
    }
    /**
     * Deletes an existing Cron Trigger.
     * @param cron - The Cron Trigger ID as a string or CronWorkflows object.
     * @returns A promise that resolves when the Cron Trigger is deleted.
     */
    delete(cron) {
        return __awaiter(this, void 0, void 0, function* () {
            const cronId = this.getCronId(cron);
            yield this.api.workflowCronDelete(this.tenantId, cronId);
        });
    }
    /**
     * Lists all Cron Triggers based on the provided query parameters.
     * @param query - Query parameters for listing Cron Triggers.
     * @returns A promise that resolves to a CronWorkflowsList object.
     */
    list(query) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.api.cronWorkflowList(this.tenantId, query);
            return response.data;
        });
    }
    /**
     * Retrieves a specific Cron Trigger by its ID.
     * @param cron - The Cron Trigger ID as a string or CronWorkflows object.
     * @returns A promise that resolves to the CronWorkflows object.
     */
    get(cron) {
        return __awaiter(this, void 0, void 0, function* () {
            const cronId = this.getCronId(cron);
            const response = yield this.api.workflowCronGet(this.tenantId, cronId);
            return response.data;
        });
    }
}
exports.CronClient = CronClient;
