import { AdminClient } from '../../admin';
import { Api } from '../../rest';
import { ScheduledWorkflows, ScheduledWorkflowsList } from '../../rest/generated/data-contracts';
import { z } from 'zod';
import { Workflow } from '../../../workflow';
import { ClientConfig } from '../client-config';
/**
 * Schema for creating a Scheduled Run Trigger.
 */
export declare const CreateScheduledRunTriggerSchema: z.ZodObject<{
    triggerAt: z.ZodDate;
    input: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
    additionalMetadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    triggerAt: Date;
    additionalMetadata?: Record<string, string> | undefined;
    input?: Record<string, any> | undefined;
}, {
    triggerAt: Date;
    additionalMetadata?: Record<string, string> | undefined;
    input?: Record<string, any> | undefined;
}>;
/**
 * Type representing the input for creating a Cron.
 */
export type CreateScheduledRunInput = z.infer<typeof CreateScheduledRunTriggerSchema>;
/**
 * Client for managing Scheduled Runs.
 */
export declare class ScheduleClient {
    private readonly tenantId;
    private readonly config;
    private readonly api;
    private readonly adminClient;
    private logger;
    /**
     * Initializes a new instance of ScheduleClient.
     * @param tenantId - The tenant identifier.
     * @param config - Client configuration settings.
     * @param api - API instance for REST interactions.
     * @param adminClient - Admin client for administrative operations.
     */
    constructor(tenantId: string, config: ClientConfig, api: Api, adminClient: AdminClient);
    /**
     * Retrieves the Scheduled Run ID from a ScheduledRun object or a string.
     * @param scheduledRun - The ScheduledRun object or Scheduled Run ID as a string.
     * @returns The Scheduled Run ID as a string.
     */
    private getScheduledRunId;
    /**
     * Creates a new Scheduled Run.
     * @param workflow - The workflow name or Workflow object.
     * @param scheduledRun - The input data for creating the Scheduled Run.
     * @returns A promise that resolves to the created ScheduledWorkflows object.
     * @throws Will throw an error if the input is invalid or the API call fails.
     */
    create(workflow: string | Workflow, cron: CreateScheduledRunInput): Promise<ScheduledWorkflows>;
    /**
     * Deletes an existing Scheduled Run.
     * @param scheduledRun - The Scheduled Run ID as a string or ScheduledWorkflows object.
     * @returns A promise that resolves when the Scheduled Run is deleted.
     */
    delete(scheduledRun: string | ScheduledWorkflows): Promise<void>;
    /**
     * Lists all Cron Triggers based on the provided query parameters.
     * @param query - Query parameters for listing Scheduled Runs.
     * @returns A promise that resolves to a ScheduledWorkflowsList object.
     */
    list(query: Parameters<typeof this.api.workflowScheduledList>[1]): Promise<ScheduledWorkflowsList>;
    /**
     * Retrieves a specific Scheduled Run by its ID.
     * @param scheduledRun - The Scheduled Run ID as a string or ScheduledWorkflows object.
     * @returns A promise that resolves to the ScheduledWorkflows object.
     */
    get(scheduledRun: string | ScheduledWorkflows): Promise<ScheduledWorkflows>;
}
