"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScheduleClient = exports.CreateScheduledRunTriggerSchema = void 0;
const zod_1 = require("zod");
const axios_1 = require("axios");
/**
 * Schema for creating a Scheduled Run Trigger.
 */
exports.CreateScheduledRunTriggerSchema = zod_1.z.object({
    triggerAt: zod_1.z.coerce.date(),
    input: zod_1.z.record(zod_1.z.any()).optional(),
    additionalMetadata: zod_1.z.record(zod_1.z.string()).optional(),
});
/**
 * Client for managing Scheduled Runs.
 */
class ScheduleClient {
    /**
     * Initializes a new instance of ScheduleClient.
     * @param tenantId - The tenant identifier.
     * @param config - Client configuration settings.
     * @param api - API instance for REST interactions.
     * @param adminClient - Admin client for administrative operations.
     */
    constructor(tenantId, config, api, adminClient) {
        this.tenantId = tenantId;
        this.config = config;
        this.api = api;
        this.adminClient = adminClient;
        this.logger = config.logger('Scheduled Run', this.config.log_level);
    }
    /**
     * Retrieves the Scheduled Run ID from a ScheduledRun object or a string.
     * @param scheduledRun - The ScheduledRun object or Scheduled Run ID as a string.
     * @returns The Scheduled Run ID as a string.
     */
    getScheduledRunId(scheduledRun) {
        return typeof scheduledRun === 'string' ? scheduledRun : scheduledRun.metadata.id;
    }
    /**
     * Creates a new Scheduled Run.
     * @param workflow - The workflow name or Workflow object.
     * @param scheduledRun - The input data for creating the Scheduled Run.
     * @returns A promise that resolves to the created ScheduledWorkflows object.
     * @throws Will throw an error if the input is invalid or the API call fails.
     */
    create(workflow, cron) {
        return __awaiter(this, void 0, void 0, function* () {
            var _a, _b, _c;
            const workflowId = typeof workflow === 'string' ? workflow : workflow.id;
            // Validate cron input with zod schema
            try {
                const parsedCron = exports.CreateScheduledRunTriggerSchema.parse(cron);
                const response = yield this.api.scheduledWorkflowRunCreate(this.tenantId, workflowId, {
                    input: (_a = parsedCron.input) !== null && _a !== void 0 ? _a : {},
                    additionalMetadata: (_b = parsedCron.additionalMetadata) !== null && _b !== void 0 ? _b : {},
                    triggerAt: parsedCron.triggerAt.toISOString(),
                });
                return response.data;
            }
            catch (err) {
                if (err instanceof zod_1.z.ZodError) {
                    throw new Error(`Invalid cron input: ${err.message}`);
                }
                if (err instanceof axios_1.AxiosError) {
                    throw new Error(JSON.stringify((_c = err.response) === null || _c === void 0 ? void 0 : _c.data.errors));
                }
                throw err;
            }
        });
    }
    /**
     * Deletes an existing Scheduled Run.
     * @param scheduledRun - The Scheduled Run ID as a string or ScheduledWorkflows object.
     * @returns A promise that resolves when the Scheduled Run is deleted.
     */
    delete(scheduledRun) {
        return __awaiter(this, void 0, void 0, function* () {
            const scheduledRunId = this.getScheduledRunId(scheduledRun);
            yield this.api.workflowScheduledDelete(this.tenantId, scheduledRunId);
        });
    }
    /**
     * Lists all Cron Triggers based on the provided query parameters.
     * @param query - Query parameters for listing Scheduled Runs.
     * @returns A promise that resolves to a ScheduledWorkflowsList object.
     */
    list(query) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.api.workflowScheduledList(this.tenantId, query);
            return response.data;
        });
    }
    /**
     * Retrieves a specific Scheduled Run by its ID.
     * @param scheduledRun - The Scheduled Run ID as a string or ScheduledWorkflows object.
     * @returns A promise that resolves to the ScheduledWorkflows object.
     */
    get(scheduledRun) {
        return __awaiter(this, void 0, void 0, function* () {
            const scheduledRunId = this.getScheduledRunId(scheduledRun);
            const response = yield this.api.workflowScheduledGet(this.tenantId, scheduledRunId);
            return response.data;
        });
    }
}
exports.ScheduleClient = ScheduleClient;
