import { ClientConfig, InternalHatchetClient, HatchetClientOptions } from '../../clients/hatchet-client';
import { AxiosRequestConfig } from 'axios';
import WorkflowRunRef from '../../util/workflow-run-ref';
import { Workflow as V0Workflow } from '../../workflow';
import { DurableContext } from '../../step';
import { Api } from '../../clients/rest';
import { CreateTaskWorkflowOpts, CreateWorkflowOpts, RunOpts, BaseWorkflowDeclaration, WorkflowDeclaration, TaskWorkflowDeclaration, CreateDurableTaskWorkflowOpts } from '../declaration';
import { IHatchetClient } from './client.interface';
import { CreateWorkerOpts, Worker } from './worker';
import { MetricsClient } from './features/metrics';
import { WorkersClient } from './features/workers';
import { WorkflowsClient } from './features/workflows';
import { RunsClient } from './features/runs';
import { InputType, OutputType, UnknownInputType, StrictWorkflowOutputType } from '../types';
import { RatelimitsClient } from './features';
/**
 * HatchetV1 implements the main client interface for interacting with the Hatchet workflow engine.
 * It provides methods for creating and executing workflows, as well as managing workers.
 */
export declare class HatchetClient implements IHatchetClient {
    /** The underlying v0 client instance */
    _v0: InternalHatchetClient;
    _api: Api;
    /**
     * @deprecated v0 client will be removed in a future release, please upgrade to v1
     */
    get v0(): InternalHatchetClient;
    /** The tenant ID for the Hatchet client */
    tenantId: string;
    _isV1: boolean | undefined;
    get isV1(): boolean;
    /**
     * Creates a new Hatchet client instance.
     * @param config - Optional configuration for the client
     * @param options - Optional client options
     * @param axiosConfig - Optional Axios configuration for HTTP requests
     */
    constructor(config?: Partial<ClientConfig>, options?: HatchetClientOptions, axiosConfig?: AxiosRequestConfig);
    /**
     * Static factory method to create a new Hatchet client instance.
     * @param config - Optional configuration for the client
     * @param options - Optional client options
     * @param axiosConfig - Optional Axios configuration for HTTP requests
     * @returns A new Hatchet client instance
     */
    static init(config?: Partial<ClientConfig>, options?: HatchetClientOptions, axiosConfig?: AxiosRequestConfig): HatchetClient;
    /**
     * Creates a new workflow definition.
     * @template I - The input type for the workflow
     * @template O - The return type of the workflow
     * @param options - Configuration options for creating the workflow
     * @returns A new Workflow instance
     * @note It is possible to create an orphaned workflow if no client is available using @hatchet/client CreateWorkflow
     */
    workflow<I extends InputType = UnknownInputType, O extends StrictWorkflowOutputType = {}>(options: CreateWorkflowOpts): WorkflowDeclaration<I, O>;
    /**
     * Creates a new task workflow.
     * Types can be explicitly specified as generics or inferred from the function signature.
     * @template I The input type for the task
     * @template O The output type of the task
     * @param options Task configuration options
     * @returns A TaskWorkflowDeclaration instance
     */
    task<I extends InputType = UnknownInputType, O extends OutputType = void>(options: CreateTaskWorkflowOpts<I, O>): TaskWorkflowDeclaration<I, O>;
    /**
     * Creates a new task workflow with types inferred from the function parameter.
     * @template Fn The type of the task function with input and output extending JsonObject
     * @param options Task configuration options with function that defines types
     * @returns A TaskWorkflowDeclaration instance with inferred types
     */
    task<Fn extends (input: I, ctx?: any) => O | Promise<O>, I extends InputType = Parameters<Fn>[0] | UnknownInputType, O extends OutputType = ReturnType<Fn> extends Promise<infer P> ? P extends OutputType ? P : void : ReturnType<Fn> extends OutputType ? ReturnType<Fn> : void>(options: {
        fn: Fn;
    } & Omit<CreateTaskWorkflowOpts<I, O>, 'fn'>): TaskWorkflowDeclaration<I, O>;
    /**
     * Creates a new durable task workflow.
     * Types can be explicitly specified as generics or inferred from the function signature.
     * @template I The input type for the durable task
     * @template O The output type of the durable task
     * @param options Durable task configuration options
     * @returns A TaskWorkflowDeclaration instance for a durable task
     */
    durableTask<I extends InputType, O extends OutputType>(options: CreateDurableTaskWorkflowOpts<I, O>): TaskWorkflowDeclaration<I, O>;
    /**
     * Creates a new durable task workflow with types inferred from the function parameter.
     * @template Fn The type of the durable task function with input and output extending JsonObject
     * @param options Durable task configuration options with function that defines types
     * @returns A TaskWorkflowDeclaration instance with inferred types
     */
    durableTask<Fn extends (input: I, ctx: DurableContext<I>) => O | Promise<O>, I extends InputType = Parameters<Fn>[0], O extends OutputType = ReturnType<Fn> extends Promise<infer P> ? P extends OutputType ? P : void : ReturnType<Fn> extends OutputType ? ReturnType<Fn> : void>(options: {
        fn: Fn;
    } & Omit<CreateDurableTaskWorkflowOpts<I, O>, 'fn'>): TaskWorkflowDeclaration<I, O>;
    /**
     * Triggers a workflow run without waiting for completion.
     * @template I - The input type for the workflow
     * @template O - The return type of the workflow
     * @param workflow - The workflow to run, either as a Workflow instance or workflow name
     * @param input - The input data for the workflow
     * @param options - Configuration options for the workflow run
     * @returns A WorkflowRunRef containing the run ID and methods to interact with the run
     */
    runNoWait<I extends InputType = UnknownInputType, O extends OutputType = void>(workflow: BaseWorkflowDeclaration<I, O> | string | V0Workflow, input: I, options: RunOpts): WorkflowRunRef<O>;
    /**
     * @alias run
     * Triggers a workflow run and waits for the result.
     * @template I - The input type for the workflow
     * @template O - The return type of the workflow
     * @param workflow - The workflow to run, either as a Workflow instance or workflow name
     * @param input - The input data for the workflow
     * @param options - Configuration options for the workflow run
     * @returns A promise that resolves with the workflow result
     */
    runAndWait<I extends InputType = UnknownInputType, O extends OutputType = void>(workflow: BaseWorkflowDeclaration<I, O> | string | V0Workflow, input: I, options?: RunOpts): Promise<O>;
    /**
     * Triggers a workflow run and waits for the result.
     * @template I - The input type for the workflow
     * @template O - The return type of the workflow
     * @param workflow - The workflow to run, either as a Workflow instance or workflow name
     * @param input - The input data for the workflow
     * @param options - Configuration options for the workflow run
     * @returns A promise that resolves with the workflow result
     */
    run<I extends InputType = UnknownInputType, O extends OutputType = void>(workflow: BaseWorkflowDeclaration<I, O> | string | V0Workflow, input: I, options?: RunOpts): Promise<O>;
    /**
     * Get the cron client for creating and managing cron workflow runs
     * @returns A cron client instance
     */
    get crons(): import("../../clients/hatchet-client/features/cron-client").CronClient;
    /**
     * Get the cron client for creating and managing cron workflow runs
     * @returns A cron client instance
     * @deprecated use client.crons instead
     */
    get cron(): import("../../clients/hatchet-client/features/cron-client").CronClient;
    /**
     * Get the schedules client for creating and managing scheduled workflow runs
     * @returns A schedules client instance
     */
    get schedules(): import("../../clients/hatchet-client/features/schedule-client").ScheduleClient;
    /**
     * Get the schedule client for creating and managing scheduled workflow runs
     * @returns A schedule client instance
     * @deprecated use client.schedules instead
     */
    get schedule(): import("../../clients/hatchet-client/features/schedule-client").ScheduleClient;
    /**
     * Get the event client for creating and managing event workflow runs
     * @returns A event client instance
     */
    get events(): import("../../clients/event/event-client").EventClient;
    /**
     * Get the event client for creating and managing event workflow runs
     * @returns A event client instance
     * @deprecated use client.events instead
     */
    get event(): import("../../clients/event/event-client").EventClient;
    private _metrics;
    /**
     * Get the metrics client for creating and managing metrics
     * @returns A metrics client instance
     */
    get metrics(): MetricsClient;
    private _ratelimits;
    /**
     * Get the rate limits client for creating and managing rate limits
     * @returns A rate limits client instance
     */
    get ratelimits(): RatelimitsClient;
    private _runs;
    /**
     * Get the runs client for creating and managing runs
     * @returns A runs client instance
     */
    get runs(): RunsClient;
    private _workflows;
    /**
     * Get the workflows client for creating and managing workflows
     * @returns A workflows client instance
     */
    get workflows(): WorkflowsClient;
    /**
     * Get the tasks client for creating and managing tasks
     * @returns A tasks client instance
     */
    get tasks(): WorkflowsClient;
    private _workers;
    /**
     * Get the workers client for creating and managing workers
     * @returns A workers client instance
     */
    get workers(): WorkersClient;
    /**
     * Get the API client for making HTTP requests to the Hatchet API
     * Note: This is not recommended for general use, but is available for advanced scenarios
     * @returns A API client instance
     */
    get api(): Api<unknown>;
    /**
     * @deprecated use workflow.run, client.run, or client.* feature methods instead
     */
    get admin(): import("../..").AdminClient;
    /**
     * Creates a new worker instance for processing workflow tasks.
     * @param options - Configuration options for creating the worker
     * @returns A promise that resolves with a new HatchetWorker instance
     */
    worker(name: string, options?: CreateWorkerOpts | number): Promise<Worker>;
    /**
     * Register a webhook with the worker
     * @param workflows - The workflows to register on the webhooks
     * @returns A promise that resolves when the webhook is registered
     */
    webhooks(workflows: V0Workflow[]): import("../../clients/worker/handler").WebhookHandler;
    runRef<T extends Record<string, any> = any>(id: string): WorkflowRunRef<T>;
}
