"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HatchetClient = void 0;
/* eslint-disable no-dupe-class-members */
/* eslint-disable no-underscore-dangle */
const hatchet_client_1 = require("../../clients/hatchet-client");
const workflow_run_ref_1 = __importDefault(require("../../util/workflow-run-ref"));
const rest_1 = __importDefault(require("../../clients/rest"));
const config_loader_1 = require("../../util/config-loader");
const hatchet_logger_1 = require("../../clients/hatchet-client/hatchet-logger");
const zod_1 = require("zod");
const declaration_1 = require("../declaration");
const worker_1 = require("./worker");
const metrics_1 = require("./features/metrics");
const workers_1 = require("./features/workers");
const workflows_1 = require("./features/workflows");
const runs_1 = require("./features/runs");
const features_1 = require("./features");
/**
 * HatchetV1 implements the main client interface for interacting with the Hatchet workflow engine.
 * It provides methods for creating and executing workflows, as well as managing workers.
 */
class HatchetClient {
    /**
     * @deprecated v0 client will be removed in a future release, please upgrade to v1
     */
    get v0() {
        return this._v0;
    }
    get isV1() {
        return true;
    }
    /**
     * Creates a new Hatchet client instance.
     * @param config - Optional configuration for the client
     * @param options - Optional client options
     * @param axiosConfig - Optional Axios configuration for HTTP requests
     */
    constructor(config, options, axiosConfig) {
        this._isV1 = true;
        try {
            const loaded = config_loader_1.ConfigLoader.loadClientConfig(config, {
                path: options === null || options === void 0 ? void 0 : options.config_path,
            });
            const valid = hatchet_client_1.ClientConfigSchema.parse(loaded);
            let logConstructor = config === null || config === void 0 ? void 0 : config.logger;
            if (logConstructor == null) {
                logConstructor = hatchet_logger_1.DEFAULT_LOGGER;
            }
            const clientConfig = Object.assign(Object.assign({}, valid), { logger: logConstructor });
            this.tenantId = clientConfig.tenant_id;
            this._api = (0, rest_1.default)(clientConfig.api_url, clientConfig.token, axiosConfig);
            this._v0 = new hatchet_client_1.InternalHatchetClient(clientConfig, options, axiosConfig, this.runs);
        }
        catch (e) {
            if (e instanceof zod_1.z.ZodError) {
                throw new Error(`Invalid client config: ${e.message}`);
            }
            throw e;
        }
    }
    /**
     * Static factory method to create a new Hatchet client instance.
     * @param config - Optional configuration for the client
     * @param options - Optional client options
     * @param axiosConfig - Optional Axios configuration for HTTP requests
     * @returns A new Hatchet client instance
     */
    static init(config, options, axiosConfig) {
        return new HatchetClient(config, options, axiosConfig);
    }
    /**
     * Creates a new workflow definition.
     * @template I - The input type for the workflow
     * @template O - The return type of the workflow
     * @param options - Configuration options for creating the workflow
     * @returns A new Workflow instance
     * @note It is possible to create an orphaned workflow if no client is available using @hatchet/client CreateWorkflow
     */
    workflow(options) {
        return (0, declaration_1.CreateWorkflow)(options, this);
    }
    /**
     * Implementation of the task method.
     */
    task(options) {
        return (0, declaration_1.CreateTaskWorkflow)(options, this);
    }
    /**
     * Implementation of the durableTask method.
     */
    durableTask(options) {
        return (0, declaration_1.CreateDurableTaskWorkflow)(options, this);
    }
    /**
     * Triggers a workflow run without waiting for completion.
     * @template I - The input type for the workflow
     * @template O - The return type of the workflow
     * @param workflow - The workflow to run, either as a Workflow instance or workflow name
     * @param input - The input data for the workflow
     * @param options - Configuration options for the workflow run
     * @returns A WorkflowRunRef containing the run ID and methods to interact with the run
     */
    runNoWait(workflow, input, options) {
        let name;
        if (typeof workflow === 'string') {
            name = workflow;
        }
        else if ('id' in workflow) {
            name = workflow.id;
        }
        else {
            throw new Error('unable to identify workflow');
        }
        return this._v0.admin.runWorkflow(name, input, options);
    }
    /**
     * @alias run
     * Triggers a workflow run and waits for the result.
     * @template I - The input type for the workflow
     * @template O - The return type of the workflow
     * @param workflow - The workflow to run, either as a Workflow instance or workflow name
     * @param input - The input data for the workflow
     * @param options - Configuration options for the workflow run
     * @returns A promise that resolves with the workflow result
     */
    runAndWait(workflow_1, input_1) {
        return __awaiter(this, arguments, void 0, function* (workflow, input, options = {}) {
            return this.run(workflow, input, options);
        });
    }
    /**
     * Triggers a workflow run and waits for the result.
     * @template I - The input type for the workflow
     * @template O - The return type of the workflow
     * @param workflow - The workflow to run, either as a Workflow instance or workflow name
     * @param input - The input data for the workflow
     * @param options - Configuration options for the workflow run
     * @returns A promise that resolves with the workflow result
     */
    run(workflow_1, input_1) {
        return __awaiter(this, arguments, void 0, function* (workflow, input, options = {}) {
            const run = this.runNoWait(workflow, input, options);
            return run.output;
        });
    }
    /**
     * Get the cron client for creating and managing cron workflow runs
     * @returns A cron client instance
     */
    get crons() {
        return this._v0.cron;
    }
    /**
     * Get the cron client for creating and managing cron workflow runs
     * @returns A cron client instance
     * @deprecated use client.crons instead
     */
    get cron() {
        return this.crons;
    }
    /**
     * Get the schedules client for creating and managing scheduled workflow runs
     * @returns A schedules client instance
     */
    get schedules() {
        return this._v0.schedule;
    }
    /**
     * Get the schedule client for creating and managing scheduled workflow runs
     * @returns A schedule client instance
     * @deprecated use client.schedules instead
     */
    get schedule() {
        return this.schedules;
    }
    /**
     * Get the event client for creating and managing event workflow runs
     * @returns A event client instance
     */
    get events() {
        return this._v0.event;
    }
    /**
     * Get the event client for creating and managing event workflow runs
     * @returns A event client instance
     * @deprecated use client.events instead
     */
    get event() {
        return this.events;
    }
    /**
     * Get the metrics client for creating and managing metrics
     * @returns A metrics client instance
     */
    get metrics() {
        if (!this._metrics) {
            this._metrics = new metrics_1.MetricsClient(this);
        }
        return this._metrics;
    }
    /**
     * Get the rate limits client for creating and managing rate limits
     * @returns A rate limits client instance
     */
    get ratelimits() {
        if (!this._ratelimits) {
            this._ratelimits = new features_1.RatelimitsClient(this);
        }
        return this._ratelimits;
    }
    /**
     * Get the runs client for creating and managing runs
     * @returns A runs client instance
     */
    get runs() {
        if (!this._runs) {
            this._runs = new runs_1.RunsClient(this);
        }
        return this._runs;
    }
    /**
     * Get the workflows client for creating and managing workflows
     * @returns A workflows client instance
     */
    get workflows() {
        if (!this._workflows) {
            this._workflows = new workflows_1.WorkflowsClient(this);
        }
        return this._workflows;
    }
    /**
     * Get the tasks client for creating and managing tasks
     * @returns A tasks client instance
     */
    get tasks() {
        return this.workflows;
    }
    /**
     * Get the workers client for creating and managing workers
     * @returns A workers client instance
     */
    get workers() {
        if (!this._workers) {
            this._workers = new workers_1.WorkersClient(this);
        }
        return this._workers;
    }
    /**
     * Get the API client for making HTTP requests to the Hatchet API
     * Note: This is not recommended for general use, but is available for advanced scenarios
     * @returns A API client instance
     */
    get api() {
        return this._api;
    }
    /**
     * @deprecated use workflow.run, client.run, or client.* feature methods instead
     */
    get admin() {
        return this._v0.admin;
    }
    /**
     * Creates a new worker instance for processing workflow tasks.
     * @param options - Configuration options for creating the worker
     * @returns A promise that resolves with a new HatchetWorker instance
     */
    worker(name, options) {
        let opts = {};
        if (typeof options === 'number') {
            opts = { slots: options };
        }
        else {
            opts = options || {};
        }
        return worker_1.Worker.create(this, this._v0, name, opts);
    }
    /**
     * Register a webhook with the worker
     * @param workflows - The workflows to register on the webhooks
     * @returns A promise that resolves when the webhook is registered
     */
    webhooks(workflows) {
        return this._v0.webhooks(workflows);
    }
    runRef(id) {
        return new workflow_run_ref_1.default(id, this.v0.listener, this.runs);
    }
}
exports.HatchetClient = HatchetClient;
