"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WorkflowsClient = exports.workflowNameString = void 0;
const workflowNameString = (workflow) => (typeof workflow === 'string' ? workflow : workflow.id);
exports.workflowNameString = workflowNameString;
/**
 * WorkflowsClient is used to list and manage workflows
 */
class WorkflowsClient {
    constructor(client, cacheTTL) {
        // Add a cache for workflows
        this.workflowCache = new Map();
        // Default cache TTL: 5 minutes (in ms)
        this.cacheTTL = 5 * 60 * 1000;
        this.api = client.api;
        this.tenantId = client.tenantId;
        // Allow custom cache TTL if provided
        if (cacheTTL !== undefined) {
            this.cacheTTL = cacheTTL;
        }
    }
    get(workflow) {
        return __awaiter(this, void 0, void 0, function* () {
            // Get workflow name string
            const name = (0, exports.workflowNameString)(workflow);
            // Check cache first
            const cached = this.workflowCache.get(name);
            if (cached && cached.expiry > Date.now()) {
                return cached.workflow;
            }
            // If not in cache or expired, fetch from API
            try {
                // Since the API only supports listing with a name filter,
                // we'll use the list endpoint with a name filter
                const { data } = yield this.api.workflowList(this.tenantId, {
                    name,
                });
                if (data && data.rows && data.rows.length > 0) {
                    const wf = data.rows[0];
                    // Cache the result
                    this.workflowCache.set(name, {
                        workflow: wf,
                        expiry: Date.now() + this.cacheTTL,
                    });
                    return workflow;
                }
                throw new Error(`Workflow with name ${name} not found`);
            }
            catch (error) {
                // Clear cache on error
                this.workflowCache.delete(name);
                throw error;
            }
        });
    }
    list(opts) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.api.workflowList(this.tenantId, opts);
            return data;
        });
    }
    delete(workflow) {
        return __awaiter(this, void 0, void 0, function* () {
            const name = (0, exports.workflowNameString)(workflow);
            try {
                // Get the workflow first to find its ID
                const workflowObj = yield this.get(name);
                if (!workflowObj || !workflowObj.metadata || !workflowObj.metadata.id) {
                    throw new Error(`Could not find workflow with name ${name}`);
                }
                const { data } = yield this.api.workflowDelete(workflowObj.metadata.id);
                // Remove from cache after deletion
                this.workflowCache.delete(name);
                return data;
            }
            catch (error) {
                // Clear cache on error
                this.workflowCache.delete(name);
                throw error;
            }
        });
    }
}
exports.WorkflowsClient = WorkflowsClient;
