import { WorkerLabels } from '../../clients/dispatcher/dispatcher-client';
import { InternalHatchetClient } from '../../clients/hatchet-client';
import { V0Worker } from '../../clients/worker';
import { Workflow as V0Workflow } from '../../workflow';
import { WebhookWorkerCreateRequest } from '../../clients/rest/generated/data-contracts';
import { BaseWorkflowDeclaration } from '../declaration';
import { HatchetClient } from '..';
/**
 * Options for creating a new hatchet worker
 * @interface CreateWorkerOpts
 */
export interface CreateWorkerOpts {
    /** (optional) Maximum number of concurrent runs on this worker, defaults to 100 */
    slots?: number;
    /** (optional) Array of workflows to register */
    workflows?: BaseWorkflowDeclaration<any, any>[] | V0Workflow[];
    /** (optional) Worker labels for affinity-based assignment */
    labels?: WorkerLabels;
    /** (optional) Whether to handle kill signals */
    handleKill?: boolean;
    /** @deprecated Use slots instead */
    maxRuns?: number;
    /** (optional) Maximum number of concurrent runs on the durable worker, defaults to 1,000 */
    durableSlots?: number;
}
/**
 * HatchetWorker class for workflow execution runtime
 */
export declare class Worker {
    config: CreateWorkerOpts;
    name: string;
    _v1: HatchetClient;
    _v0: InternalHatchetClient;
    /** Internal reference to the underlying V0 worker implementation */
    nonDurable: V0Worker;
    durable?: V0Worker;
    /**
     * Creates a new HatchetWorker instance
     * @param nonDurable - The V0 worker implementation
     */
    constructor(v1: HatchetClient, v0: InternalHatchetClient, nonDurable: V0Worker, config: CreateWorkerOpts, name: string);
    /**
     * Creates and initializes a new HatchetWorker
     * @param v0 - The HatchetClient instance
     * @param options - Worker creation options
     * @returns A new HatchetWorker instance
     */
    static create(v1: HatchetClient, v0: InternalHatchetClient, name: string, options: CreateWorkerOpts): Promise<Worker>;
    /**
     * Registers workflows with the worker
     * @param workflows - Array of workflows to register
     * @returns Array of registered workflow promises
     */
    registerWorkflows(workflows?: Array<BaseWorkflowDeclaration<any, any> | V0Workflow>): Promise<void[]>;
    /**
     * Registers a single workflow with the worker
     * @param workflow - The workflow to register
     * @returns A promise that resolves when the workflow is registered
     * @deprecated use registerWorkflows instead
     */
    registerWorkflow(workflow: BaseWorkflowDeclaration<any, any> | V0Workflow): Promise<void[]>;
    /**
     * Starts the worker
     * @returns Promise that resolves when the worker is stopped or killed
     */
    start(): Promise<void[]>;
    /**
     * Stops the worker
     * @returns Promise that resolves when the worker stops
     */
    stop(): Promise<void[]>;
    /**
     * Updates or inserts worker labels
     * @param labels - Worker labels to update
     * @returns Promise that resolves when labels are updated
     */
    upsertLabels(labels: WorkerLabels): Promise<WorkerLabels>;
    /**
     * Get the labels for the worker
     * @returns The labels for the worker
     */
    getLabels(): WorkerLabels;
    /**
     * Register a webhook with the worker
     * @param webhook - The webhook to register
     * @returns A promise that resolves when the webhook is registered
     */
    registerWebhook(webhook: WebhookWorkerCreateRequest): Promise<import("axios").AxiosResponse<import("../../clients/rest/generated/data-contracts").WebhookWorkerCreated, any>>;
    isPaused(): Promise<boolean>;
    pause(): Promise<any[]>;
    unpause(): Promise<any[]>;
}
