"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Worker = void 0;
const declaration_1 = require("../declaration");
const DEFAULT_DURABLE_SLOTS = 1000;
/**
 * HatchetWorker class for workflow execution runtime
 */
class Worker {
    /**
     * Creates a new HatchetWorker instance
     * @param nonDurable - The V0 worker implementation
     */
    constructor(v1, v0, nonDurable, config, name) {
        this._v1 = v1;
        this._v0 = v0;
        this.nonDurable = nonDurable;
        this.config = config;
        this.name = name;
    }
    /**
     * Creates and initializes a new HatchetWorker
     * @param v0 - The HatchetClient instance
     * @param options - Worker creation options
     * @returns A new HatchetWorker instance
     */
    static create(v1, v0, name, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const v0worker = yield v0.worker(name, Object.assign(Object.assign({}, options), { maxRuns: options.slots || options.maxRuns }));
            const worker = new Worker(v1, v0, v0worker, options, name);
            yield worker.registerWorkflows(options.workflows);
            return worker;
        });
    }
    /**
     * Registers workflows with the worker
     * @param workflows - Array of workflows to register
     * @returns Array of registered workflow promises
     */
    registerWorkflows(workflows) {
        return __awaiter(this, void 0, void 0, function* () {
            return Promise.all((workflows === null || workflows === void 0 ? void 0 : workflows.map((wf) => __awaiter(this, void 0, void 0, function* () {
                if (wf instanceof declaration_1.BaseWorkflowDeclaration) {
                    // TODO check if tenant is V1
                    const register = this.nonDurable.registerWorkflowV1(wf);
                    if (wf.definition._durableTasks.length > 0) {
                        if (!this.durable) {
                            this.durable = yield this._v0.worker(`${this.name}-durable`, Object.assign(Object.assign({}, this.config), { maxRuns: this.config.durableSlots || DEFAULT_DURABLE_SLOTS }));
                        }
                        this.durable.registerDurableActionsV1(wf.definition);
                    }
                    return register;
                }
                // fallback to v0 client for backwards compatibility
                return this.nonDurable.registerWorkflow(wf);
            }))) || []);
        });
    }
    /**
     * Registers a single workflow with the worker
     * @param workflow - The workflow to register
     * @returns A promise that resolves when the workflow is registered
     * @deprecated use registerWorkflows instead
     */
    registerWorkflow(workflow) {
        return this.registerWorkflows([workflow]);
    }
    /**
     * Starts the worker
     * @returns Promise that resolves when the worker is stopped or killed
     */
    start() {
        const workers = [this.nonDurable];
        if (this.durable) {
            workers.push(this.durable);
        }
        return Promise.all(workers.map((w) => w.start()));
    }
    /**
     * Stops the worker
     * @returns Promise that resolves when the worker stops
     */
    stop() {
        const workers = [this.nonDurable];
        if (this.durable) {
            workers.push(this.durable);
        }
        return Promise.all(workers.map((w) => w.stop()));
    }
    /**
     * Updates or inserts worker labels
     * @param labels - Worker labels to update
     * @returns Promise that resolves when labels are updated
     */
    upsertLabels(labels) {
        return this.nonDurable.upsertLabels(labels);
    }
    /**
     * Get the labels for the worker
     * @returns The labels for the worker
     */
    getLabels() {
        return this.nonDurable.labels;
    }
    /**
     * Register a webhook with the worker
     * @param webhook - The webhook to register
     * @returns A promise that resolves when the webhook is registered
     */
    registerWebhook(webhook) {
        return this.nonDurable.registerWebhook(webhook);
    }
    isPaused() {
        return __awaiter(this, void 0, void 0, function* () {
            var _a, _b;
            const promises = [];
            if ((_a = this.nonDurable) === null || _a === void 0 ? void 0 : _a.workerId) {
                promises.push(this._v1.workers.isPaused(this.nonDurable.workerId));
            }
            if ((_b = this.durable) === null || _b === void 0 ? void 0 : _b.workerId) {
                promises.push(this._v1.workers.isPaused(this.durable.workerId));
            }
            const res = yield Promise.all(promises);
            return !res.includes(false);
        });
    }
    // TODO docstrings
    pause() {
        var _a, _b;
        const promises = [];
        if ((_a = this.nonDurable) === null || _a === void 0 ? void 0 : _a.workerId) {
            promises.push(this._v1.workers.pause(this.nonDurable.workerId));
        }
        if ((_b = this.durable) === null || _b === void 0 ? void 0 : _b.workerId) {
            promises.push(this._v1.workers.pause(this.durable.workerId));
        }
        return Promise.all(promises);
    }
    unpause() {
        var _a, _b;
        const promises = [];
        if ((_a = this.nonDurable) === null || _a === void 0 ? void 0 : _a.workerId) {
            promises.push(this._v1.workers.unpause(this.nonDurable.workerId));
        }
        if ((_b = this.durable) === null || _b === void 0 ? void 0 : _b.workerId) {
            promises.push(this._v1.workers.unpause(this.durable.workerId));
        }
        return Promise.all(promises);
    }
}
exports.Worker = Worker;
