"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskWorkflowDeclaration = exports.WorkflowDeclaration = exports.BaseWorkflowDeclaration = void 0;
exports.CreateTaskWorkflow = CreateTaskWorkflow;
exports.CreateWorkflow = CreateWorkflow;
exports.CreateDurableTaskWorkflow = CreateDurableTaskWorkflow;
const UNBOUND_ERR = new Error('workflow unbound to hatchet client, hint: use client.run instead');
/**
 * Represents a workflow that can be executed by Hatchet.
 * @template I The input type for the workflow.
 * @template O The return type of the workflow.
 */
class BaseWorkflowDeclaration {
    /**
     * Creates a new workflow instance.
     * @param options The options for creating the workflow.
     * @param client Optional Hatchet client instance.
     */
    constructor(options, client) {
        this.definition = Object.assign(Object.assign({}, options), { _tasks: [], _durableTasks: [] });
        this.client = client;
    }
    /**
     * Triggers a workflow run without waiting for completion.
     * @param input The input data for the workflow.
     * @param options Optional configuration for this workflow run.
     * @returns A WorkflowRunRef containing the run ID and methods to get results and interact with the run.
     * @throws Error if the workflow is not bound to a Hatchet client.
     */
    runNoWait(input, options, _standaloneTaskName) {
        if (!this.client) {
            throw UNBOUND_ERR;
        }
        const res = this.client._v0.admin.runWorkflow(this.name, input, options);
        if (_standaloneTaskName) {
            res._standalone_task_name = _standaloneTaskName;
        }
        return res;
    }
    runAndWait(input, options, _standaloneTaskName) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.client) {
                throw UNBOUND_ERR;
            }
            if (Array.isArray(input)) {
                return Promise.all(input.map((i) => this.runAndWait(i, options, _standaloneTaskName)));
            }
            return this.run(input, options, _standaloneTaskName);
        });
    }
    run(input, options, _standaloneTaskName) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.client) {
                throw UNBOUND_ERR;
            }
            if (Array.isArray(input)) {
                let resp = [];
                for (let i = 0; i < input.length; i += 500) {
                    const batch = input.slice(i, i + 500);
                    const batchResp = yield this.client._v0.admin.runWorkflows(batch.map((inp) => ({
                        workflowName: this.definition.name,
                        input: inp,
                        options,
                    })));
                    resp = resp.concat(batchResp);
                }
                const res = [];
                resp.forEach((ref, index) => {
                    const wf = input[index].workflow;
                    if (wf instanceof TaskWorkflowDeclaration) {
                        // eslint-disable-next-line no-param-reassign
                        ref._standalone_task_name = wf._standalone_task_name;
                    }
                    res.push(ref.result());
                });
                return Promise.all(res);
            }
            const res = this.client._v0.admin.runWorkflow(this.definition.name, input, options);
            if (_standaloneTaskName) {
                res._standalone_task_name = _standaloneTaskName;
            }
            return res.result();
        });
    }
    /**
     * Schedules a workflow to run at a specific date and time in the future.
     * @param enqueueAt The date when the workflow should be triggered.
     * @param input The input data for the workflow.
     * @param options Optional configuration for this workflow run.
     * @returns A promise that resolves with the scheduled workflow details.
     * @throws Error if the workflow is not bound to a Hatchet client.
     */
    schedule(enqueueAt, input, options) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.client) {
                throw UNBOUND_ERR;
            }
            const scheduled = this.client._v0.schedule.create(this.definition.name, {
                triggerAt: enqueueAt,
                input: input,
                additionalMetadata: options === null || options === void 0 ? void 0 : options.additionalMetadata,
            });
            return scheduled;
        });
    }
    /**
     * Schedules a workflow to run after a specified delay.
     * @param duration The delay in seconds before the workflow should run.
     * @param input The input data for the workflow.
     * @param options Optional configuration for this workflow run.
     * @returns A promise that resolves with the scheduled workflow details.
     * @throws Error if the workflow is not bound to a Hatchet client.
     */
    delay(duration, input, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const now = Date.now();
            const triggerAt = new Date(now + duration * 1000);
            return this.schedule(triggerAt, input, options);
        });
    }
    /**
     * Creates a cron schedule for the workflow.
     * @param name The name of the cron schedule.
     * @param expression The cron expression defining the schedule.
     * @param input The input data for the workflow.
     * @param options Optional configuration for this workflow run.
     * @returns A promise that resolves with the cron workflow details.
     * @throws Error if the workflow is not bound to a Hatchet client.
     */
    cron(name, expression, input, options) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.client) {
                throw UNBOUND_ERR;
            }
            const cronDef = this.client._v0.cron.create(this.definition.name, {
                expression,
                input: input,
                additionalMetadata: options === null || options === void 0 ? void 0 : options.additionalMetadata,
                name,
            });
            return cronDef;
        });
    }
    /**
     * Get metrics for the workflow.
     * @param opts Optional configuration for the metrics request.
     * @returns A promise that resolves with the workflow metrics.
     * @throws Error if the workflow is not bound to a Hatchet client.
     */
    metrics(opts) {
        if (!this.client) {
            throw UNBOUND_ERR;
        }
        return this.client.metrics.getWorkflowMetrics(this.definition.name, opts);
    }
    /**
     * Get queue metrics for the workflow.
     * @param opts Optional configuration for the metrics request.
     * @returns A promise that resolves with the workflow metrics.
     * @throws Error if the workflow is not bound to a Hatchet client.
     */
    queueMetrics(opts) {
        if (!this.client) {
            throw UNBOUND_ERR;
        }
        return this.client.metrics.getQueueMetrics(Object.assign(Object.assign({}, opts), { workflows: [this.definition.name] }));
    }
    /**
     * Get the current state of the workflow.
     * @returns A promise that resolves with the workflow state.
     * @throws Error if the workflow is not bound to a Hatchet client.
     */
    get() {
        if (!this.client) {
            throw UNBOUND_ERR;
        }
        return this.client.workflows.get(this);
    }
    // // gets the pause state of the workflow
    // isPaused() {
    //   if (!this.client) {
    //     throw UNBOUND_ERR;
    //   }
    //   return this.client.workflows.isPaused(this);
    // }
    // // pause assignment of workflow
    // pause() {
    //   if (!this.client) {
    //     throw UNBOUND_ERR;
    //   }
    //   return this.client.workflows.pause(this);
    // }
    // // unpause assignment of workflow
    // unpause() {
    //   if (!this.client) {
    //     throw UNBOUND_ERR;
    //   }
    //   return this.client.workflows.unpause(this);
    // }
    // @deprecated use definition.name instead
    get id() {
        return this.definition.name;
    }
    /**
     * Get the friendly name of the workflow.
     * @returns The name of the workflow.
     */
    get name() {
        return this.definition.name;
    }
}
exports.BaseWorkflowDeclaration = BaseWorkflowDeclaration;
class WorkflowDeclaration extends BaseWorkflowDeclaration {
    /**
     * Adds a task to the workflow.
     * The return type will be either the property on O that corresponds to the task name,
     * or if there is no matching property, the inferred return type of the function.
     * @template Name The literal string name of the task.
     * @template Fn The type of the task function.
     * @param options The task configuration options.
     * @returns The task options that were added.
     */
    task(options) {
        let typedOptions;
        if (options instanceof TaskWorkflowDeclaration) {
            typedOptions = options.taskDef;
        }
        else {
            typedOptions = options;
        }
        this.definition._tasks.push(typedOptions);
        return typedOptions;
    }
    /**
     * Adds an onFailure task to the workflow.
     * This will only run if any task in the workflow fails.
     * @template Name The literal string name of the task.
     * @template L The inferred return type of the task function.
     * @param options The task configuration options.
     * @returns The task options that were added.
     */
    onFailure(options) {
        var _a;
        let typedOptions;
        if (options instanceof TaskWorkflowDeclaration) {
            typedOptions = options.taskDef;
        }
        else {
            typedOptions = options;
        }
        if (this.definition.onFailure) {
            (_a = this.client) === null || _a === void 0 ? void 0 : _a._v0.logger.warn(`onFailure task will override existing onFailure task`);
        }
        this.definition.onFailure = typedOptions;
        return typedOptions;
    }
    /**
     * Adds an onSuccess task to the workflow.
     * This will only run if all tasks in the workflow complete successfully.
     * @template Name The literal string name of the task.
     * @template L The inferred return type of the task function.
     * @param options The task configuration options.
     * @returns The task options that were added.
     */
    onSuccess(options) {
        var _a;
        let typedOptions;
        if (options instanceof TaskWorkflowDeclaration) {
            typedOptions = options.taskDef;
        }
        else {
            typedOptions = options;
        }
        if (this.definition.onSuccess) {
            (_a = this.client) === null || _a === void 0 ? void 0 : _a._v0.logger.warn(`onSuccess task will override existing onSuccess task`);
        }
        this.definition.onSuccess = typedOptions;
        return typedOptions;
    }
    /**
     * Adds a durable task to the workflow.
     * The return type will be either the property on O that corresponds to the task name,
     * or if there is no matching property, the inferred return type of the function.
     * @template Name The literal string name of the task.
     * @template Fn The type of the task function.
     * @param options The task configuration options.
     * @returns The task options that were added.
     */
    durableTask(options) {
        const typedOptions = options;
        this.definition._durableTasks.push(typedOptions);
        return typedOptions;
    }
}
exports.WorkflowDeclaration = WorkflowDeclaration;
class TaskWorkflowDeclaration extends BaseWorkflowDeclaration {
    constructor(options, client) {
        super(Object.assign({}, options), client);
        this._standalone_task_name = options.name;
        this.definition._tasks.push(Object.assign({}, options));
    }
    run(input, options) {
        const _super = Object.create(null, {
            run: { get: () => super.run }
        });
        return __awaiter(this, void 0, void 0, function* () {
            return (yield _super.run.call(this, input, options, this._standalone_task_name));
        });
    }
    /**
     * Triggers a workflow run without waiting for completion.
     * @param input The input data for the workflow.
     * @param options Optional configuration for this workflow run.
     * @returns A WorkflowRunRef containing the run ID and methods to get results and interact with the run.
     * @throws Error if the workflow is not bound to a Hatchet client.
     */
    runNoWait(input, options) {
        if (!this.client) {
            throw UNBOUND_ERR;
        }
        return super.runNoWait(input, options, this._standalone_task_name);
    }
    get taskDef() {
        return this.definition._tasks[0];
    }
}
exports.TaskWorkflowDeclaration = TaskWorkflowDeclaration;
/**
 * Creates a new task workflow declaration with types inferred from the function parameter.
 * @template Fn The type of the task function
 * @param options The task configuration options.
 * @param client Optional Hatchet client instance.
 * @returns A new TaskWorkflowDeclaration with inferred types.
 */
function CreateTaskWorkflow(options, client) {
    return new TaskWorkflowDeclaration(options, client);
}
/**
 * Creates a new workflow instance.
 * @template I The input type for the workflow.
 * @template O The return type of the workflow.
 * @param options The options for creating the workflow.
 * @param client Optional Hatchet client instance.
 * @returns A new Workflow instance.
 */
function CreateWorkflow(options, client) {
    return new WorkflowDeclaration(options, client);
}
/**
 * Creates a new durable task workflow declaration with types inferred from the function parameter.
 * @template Fn The type of the durable task function
 * @param options The durable task configuration options.
 * @param client Optional Hatchet client instance.
 * @returns A new TaskWorkflowDeclaration with inferred types.
 */
function CreateDurableTaskWorkflow(options, client) {
    // Note: We're using TaskWorkflowDeclaration here since task and durableTask
    // share the same declaration structure but with different task types
    const taskWorkflow = new TaskWorkflowDeclaration(options, client);
    // Move the task from tasks to durableTasks
    if (taskWorkflow.definition._tasks.length > 0) {
        const task = taskWorkflow.definition._tasks[0];
        taskWorkflow.definition._tasks = [];
        taskWorkflow.definition._durableTasks.push(task);
    }
    return taskWorkflow;
}
